curver\.kernel package
======================

Submodules
----------

curver\.kernel\.arc module
--------------------------

.. automodule:: curver.kernel.arc
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.crush module
----------------------------

.. automodule:: curver.kernel.crush
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.curve module
----------------------------

.. automodule:: curver.kernel.curve
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.curvecomplex module
-----------------------------------

.. automodule:: curver.kernel.curvecomplex
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.encoding module
-------------------------------

.. automodule:: curver.kernel.encoding
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.error module
----------------------------

.. automodule:: curver.kernel.error
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.homology module
-------------------------------

.. automodule:: curver.kernel.homology
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.lamination module
---------------------------------

.. automodule:: curver.kernel.lamination
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.mappingclassgroup module
----------------------------------------

.. automodule:: curver.kernel.mappingclassgroup
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.moves module
----------------------------

.. automodule:: curver.kernel.moves
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.partition module
--------------------------------

.. automodule:: curver.kernel.partition
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.permutation module
----------------------------------

.. automodule:: curver.kernel.permutation
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.traintrack module
---------------------------------

.. automodule:: curver.kernel.traintrack
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.triangulation module
------------------------------------

.. automodule:: curver.kernel.triangulation
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.twist module
----------------------------

.. automodule:: curver.kernel.twist
    :members:
    :undoc-members:
    :show-inheritance:

curver\.kernel\.utilities module
--------------------------------

.. automodule:: curver.kernel.utilities
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: curver.kernel
    :members:
    :undoc-members:
    :show-inheritance:
